summaryrefslogtreecommitdiffstats
path: root/native/src/image.rs
diff options
context:
space:
mode:
Diffstat (limited to 'native/src/image.rs')
-rw-r--r--native/src/image.rs31
1 files changed, 18 insertions, 13 deletions
diff --git a/native/src/image.rs b/native/src/image.rs
index 516eb2db..06fd7ae6 100644
--- a/native/src/image.rs
+++ b/native/src/image.rs
@@ -1,6 +1,7 @@
//! Load and draw raster graphics.
-use crate::{Hasher, Rectangle};
+use crate::{Hasher, Rectangle, Size};
+use std::borrow::Cow;
use std::hash::{Hash, Hasher as _};
use std::path::PathBuf;
use std::sync::Arc;
@@ -21,15 +22,19 @@ impl Handle {
}
/// Creates an image [`Handle`] containing the image pixels directly. This
/// function expects the input data to be provided as a `Vec<u8>` of BGRA
/// pixels.
///
/// This is useful if you have already decoded your image.
- pub fn from_pixels(width: u32, height: u32, pixels: Vec<u8>) -> Handle {
- Self::from_data(Data::Pixels {
+ pub fn from_pixels(
+ width: u32,
+ height: u32,
+ pixels: impl Into<Cow<'static, [u8]>>,
+ ) -> Handle {
+ Self::from_data(Data::Rgba {
width,
height,
- pixels,
+ pixels: pixels.into(),
})
}
@@ -39,8 +44,8 @@ impl Handle {
///
/// This is useful if you already have your image loaded in-memory, maybe
/// because you downloaded or generated it procedurally.
- pub fn from_memory(bytes: Vec<u8>) -> Handle {
- Self::from_data(Data::Bytes(bytes))
+ pub fn from_memory(bytes: impl Into<Cow<'static, [u8]>>) -> Handle {
+ Self::from_data(Data::Bytes(bytes.into()))
}
fn from_data(data: Data) -> Handle {
@@ -86,16 +91,16 @@ pub enum Data {
Path(PathBuf),
/// In-memory data
- Bytes(Vec<u8>),
+ Bytes(Cow<'static, [u8]>),
- /// Decoded image pixels in BGRA format.
- Pixels {
+ /// Decoded image pixels in RGBA format.
+ Rgba {
/// The width of the image.
width: u32,
/// The height of the image.
height: u32,
/// The pixels.
- pixels: Vec<u8>,
+ pixels: Cow<'static, [u8]>,
},
}
@@ -104,7 +109,7 @@ impl std::fmt::Debug for Data {
match self {
Data::Path(path) => write!(f, "Path({:?})", path),
Data::Bytes(_) => write!(f, "Bytes(...)"),
- Data::Pixels { width, height, .. } => {
+ Data::Rgba { width, height, .. } => {
write!(f, "Pixels({} * {})", width, height)
}
}
@@ -121,7 +126,7 @@ pub trait Renderer: crate::Renderer {
type Handle: Clone + Hash;
/// Returns the dimensions of an image for the given [`Handle`].
- fn dimensions(&self, handle: &Self::Handle) -> (u32, u32);
+ fn dimensions(&self, handle: &Self::Handle) -> Size<u32>;
/// Draws an image with the given [`Handle`] and inside the provided
/// `bounds`.
@@ -21,15 +22,19 @@ impl Handle {
}
/// Creates an image [`Handle`] containing the image pixels directly. This
- /// function expects the input data to be provided as a `Vec<u8>` of BGRA
+ /// function expects the input data to be provided as a `Vec<u8>` of RGBA
/// pixels.
///